@@ -1203,7 +1203,7 @@ function rrule_expand( $dtstart, $property, $component, $range_end, $is_date=nul
 *
 * @return vComponent The original vComponent, with the instances of the internal components expanded.
 */
-function expand_event_instances( vComponent $vResource, $range_start = null, $range_end = null, $return_floating_times=false ) {
+function expand_event_instances( vComponent $vResource, $range_start = null, $range_end = null, $return_floating_times=false, $fallback_tzid=null ) {
     global $c;
     $components = $vResource->GetComponents();
 
@@ -1302,7 +1302,7 @@ function expand_event_instances( vComponent $vResource, $range_start = null, $ra
       }
       print "\n";
     }
-    $instances += rrule_expand($dtstart, 'RRULE', $comp, $range_end, null, $return_floating_times);
+    $instances += rrule_expand($dtstart, 'RRULE', $comp, $range_end, null, $return_floating_times, $fallback_tzid);
     if ( DEBUG_RRULE ) {
       print( "After rrule_expand");
       foreach( $instances AS $k => $v ) {
@@ -1449,10 +1449,11 @@ function expand_event_instances( vComponent $vResource, $range_start = null, $ra
 /**
  * Return a date range for this component.
  * @param vComponent $comp
+ * @param string $fallback_tzid Default timezone to use, if any
  * @throws Exception (1) When DTSTART is not present but the RFC says MUST and (2) when we get an unsupported component
  * @return RepeatRuleDateRange
  */
-function getComponentRange(vComponent $comp, string $fallback_tzid = null) {
+function getComponentRange(vComponent $comp, $fallback_tzid = null) {
   $dtstart_prop = $comp->GetProperty('DTSTART');
   $duration_prop = $comp->GetProperty('DURATION');
   if ( isset($duration_prop) ) {
@@ -1476,6 +1477,7 @@ function getComponentRange(vComponent $comp, string $fallback_tzid = null) {
         if ( !isset($dtstart_prop) )
           $dtstart_prop = $comp->GetProperty('DTSTAMP');
         $dtend_prop = $dtstart_prop;
+        break;
       default:
         throw new Exception('getComponentRange cannot handle "'.$comp->GetType().'" components', 0);
     }
@@ -1505,9 +1507,10 @@ function getComponentRange(vComponent $comp, string $fallback_tzid = null) {
 * @todo: This should probably be made part of the VCalendar object when we move the RRule.php into AWL.
 *
 * @param object $vResource A vComponent which is a VCALENDAR containing components needing expansion
+* @param string $fallback_tzid Default timezone to use, if any
 * @return RepeatRuleDateRange Representing the range of time covered by the event.
 */
-function getVCalendarRange( $vResource, string $fallback_tzid = null ) {
+function getVCalendarRange( $vResource, $fallback_tzid = null ) {
   $components = $vResource->GetComponents();
 
   $dtstart = null;
